Module: Yandex360

Defined in:
lib/yandex360/error.rb,
lib/yandex360/rails.rb,
lib/yandex360/client.rb,
lib/yandex360/record.rb,
lib/yandex360/railtie.rb,
lib/yandex360/version.rb,
lib/yandex360/resource.rb,
lib/yandex360/collection.rb,
lib/yandex360/configuration.rb,
lib/yandex360/objects/types.rb,
lib/yandex360/param_builder.rb,
lib/yandex360/resources/dns.rb,
lib/yandex360/instrumentation.rb,
lib/yandex360/resources/audit.rb,
lib/yandex360/resources/users.rb,
lib/yandex360/resources/groups.rb,
lib/yandex360/resources/two_fa.rb,
lib/yandex360/resources/domains.rb,
lib/yandex360/resources/routing.rb,
lib/yandex360/resources/antispam.rb,
lib/yandex360/resources/sessions.rb,
lib/yandex360/resources/mailboxes.rb,
lib/yandex360/resources/passwords.rb,
lib/yandex360/resources/departments.rb,
lib/yandex360/resources/mail_settings.rb,
lib/yandex360/resources/organizations.rb,
lib/yandex360/resources/domain_policies.rb,
lib/yandex360/resources/external_contacts.rb,
lib/yandex360/resources/service_applications.rb

Defined Under Namespace

Modules: Instrumentation, ParamBuilder, Rails Classes: Alias, AllowList, AntispamResource, AuditEvent, AuditResource, AuthenticationError, AuthorizationError, Client, Collection, Configuration, Department, DepartmentAlias, DepartmentsResource, DnsRecord, DnsResource, Domain, Domain2FA, DomainDkim, DomainPassword, DomainPoliciesResource, DomainPolicy, DomainSession, DomainStatus, DomainsResource, Error, ExternalContact, ExternalContactsResource, Group, GroupMembers, GroupsResource, MailAddressBook, MailRule, MailSenderInfo, MailSettingsResource, MailUserRules, Mailbox, MailboxActor, MailboxResource, MailboxTask, MailboxesResource, NotFoundError, Organization, OrganizationsResource, PasswordsResource, Railtie, RateLimitError, Record, Resource, Response, RoutingResource, RoutingRules, ServerError, ServiceApplication, ServiceApplicationsResource, SessionsResource, TwoFaResource, User, User2FA, UsersResource, ValidationError

Constant Summary collapse

VERSION =
"4.0.0"

Class Method Summary collapse

Class Method Details

.config ⇒ Object



60
61
62
# File 'lib/yandex360/configuration.rb', line 60

def config
  @config ||= Configuration.new
end

.configure {|config| ... } ⇒ Object

Yields:



64
65
66
67
# File 'lib/yandex360/configuration.rb', line 64

def configure
  yield config
  config
end

.on(event_name, &block) ⇒ Object

See Yandex360::Instrumentation. Only :request is published today; the argument is taken so that adding another kind later does not change how this is called.

Raises:

  • (ArgumentError)


126
127
128
129
130
# File 'lib/yandex360/instrumentation.rb', line 126

def on(event_name, &block)
  raise ArgumentError, "Unknown event #{event_name}" unless event_name == :request

  Instrumentation.subscribe(&block)
end

.reset_config! ⇒ Object

Mainly for tests, which need each example to start from a known state.



70
71
72
# File 'lib/yandex360/configuration.rb', line 70

def reset_config!
  @config = Configuration.new
end